==> haskell-aws-0.24.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-7ACdiFUcRGm8jG3eIbCRGl
key:                  aws-0.24.1-7ACdiFUcRGm8jG3eIbCRGl
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  f0d009fbcffbc5dee2fa9949d71dbe21
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-7ACdiFUcRGm8jG3eIbCRGl
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    attoparsec-0.14.4-AfQEBsI4KfUBbsB9NxUVAd base-4.17.2.1
    base16-bytestring-1.0.2.0-3kwon8iNzO25udiTa31L4P
    base64-bytestring-1.2.1.0-ITj2xakY1ml2q5A6QmvnkU
    blaze-builder-0.4.4-6Kuq6wnWuSiCILCubQnlxM
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-FxzwbfXGSRtJvuZXIFUaJZ
    conduit-extra-1.3.8-EBS8kSAFBch1v5ZzaSbjvA containers-0.6.7
    cryptonite-0.30-AmavgpeHcT46aE11pYkBRq
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-JPbMvFYYazPC4HKKOIQQxM
    http-conduit-2.3.9.1-FnzYP5U7g9FDzbDtt4ESz8
    http-types-0.12.4-DI0pM0gIACkLbu0K6LN6Y6
    lifted-base-0.2.3.12-j7qVxKd7nW4LJGVtPXD5y
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-9zo0UMe5gnjLVD9yuioV4p mtl-2.2.2
    network-3.1.4.0-1Bok7DDOmdQ7OlyZLPDJ7H
    network-bsd-2.8.1.0-3vouKFKPuJxRPZurkP2cG
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-KFdVdoMdUy2HAqiIe2FuFP
    safe-0.3.21-85eF7qPff6wBGTusoDGORM
    scientific-0.3.8.0-KXoba1fOMYH676R2WXZfYW
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS
    xml-conduit-1.9.1.4-8FhwcO2FTQSFazR5N5lT2S

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.24.1-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-5VMku0JI4prIUI9G4Iwy1I
key:                  aws-0.24.1-5VMku0JI4prIUI9G4Iwy1I
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  054a12b6d846f679e41ddb37bed2cded
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-5VMku0JI4prIUI9G4Iwy1I
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    attoparsec-0.14.4-AfQEBsI4KfUBbsB9NxUVAd base-4.17.2.1
    base16-bytestring-1.0.2.0-3kwon8iNzO25udiTa31L4P
    base64-bytestring-1.2.1.0-ITj2xakY1ml2q5A6QmvnkU
    blaze-builder-0.4.4-6Kuq6wnWuSiCILCubQnlxM
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-5V2PSjSHeYS5sF2XpXfdrm
    conduit-extra-1.3.8-AFR5r0hqxtKmjLH3pCwC0 containers-0.6.7
    cryptonite-0.30-AmavgpeHcT46aE11pYkBRq
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-JPbMvFYYazPC4HKKOIQQxM
    http-conduit-2.3.9.1-4fJpFUSyBe2kREJOIVncV
    http-types-0.12.4-DI0pM0gIACkLbu0K6LN6Y6
    lifted-base-0.2.3.12-j7qVxKd7nW4LJGVtPXD5y
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-9zo0UMe5gnjLVD9yuioV4p mtl-2.2.2
    network-3.1.4.0-1Bok7DDOmdQ7OlyZLPDJ7H
    network-bsd-2.8.1.0-3vouKFKPuJxRPZurkP2cG
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-KFdVdoMdUy2HAqiIe2FuFP
    safe-0.3.21-85eF7qPff6wBGTusoDGORM
    scientific-0.3.8.0-KXoba1fOMYH676R2WXZfYW
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS
    xml-conduit-1.9.1.4-EcFbko88JTi3RpbKuTwS7r

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
